#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY

#undef PACKAGE
#undef VERSION
#undef USE_GTK24

#undef TMAID_BUILD_ENVIRONMENT
